<?php

/**
 * Prevent the loading of patterns from the WordPress.org Pattern Directory
 */
add_filter( 'should_load_remote_block_patterns', '__return_false' );

/**
 * Remove patterns that ship with WordPress Core
 */
add_action( 'after_setup_theme', 'osom_remove_core_block_patterns' );
function osom_remove_core_block_patterns() {
	remove_theme_support( 'core-block-patterns' );
}

/**
 * Unregister block patterns if contained blocks are not registered
 */
add_action( 'init', 'osom_unregister_patterns', 999 );
function osom_unregister_patterns() {
	$blocks = WP_Block_Type_Registry::get_instance();

	$unregister = [
		'edd/downloads'  => [
			'dakota-next/edd-grid'
		]
	];

	foreach ( $unregister as $block => $patterns ) {
		if ( ! $blocks->is_registered( $block ) ) {
			foreach ( $patterns as $pattern ) {
				unregister_block_pattern( $pattern );
			}
		}
	}
}

/**
 * Register new patterns category
 */
add_action( 'init', 'osom_register_patterns' );
function osom_register_patterns() {
	if ( function_exists( 'register_block_pattern_category' ) ) {
		register_block_pattern_category(
			'osompress',
			array(
				'label'       => __( 'OsomPress', 'dakota-next' ),
				'description' => __( 'OsomPress themes patterns', 'dakota-next' ),
			)
		);

		register_block_pattern_category(
			'osom-page-layouts',
			array(
				'label'       => __( 'Osom Page Layouts', 'dakota-next' ),
				'description' => __( 'OsomPress whole page patterns', 'dakota-next' ),
			)
		);
	}
}

/**
 * Register block styles
 */
add_action( 'init', 'osom_register_block_styles' );
function osom_register_block_styles() {

	register_block_style( 'core/list', array(
		'name'         => 'osom-list-with-check-icon',
		'label'        => __( 'Big Checkbox', 'dakota-next' ),
		'inline_style' => '.is-style-osom-list-with-check-icon {list-style: none;padding-left: 0;}.is-style-osom-list-with-check-icon li {position: relative;padding-left: 80px;margin: 30px 30px 30px 0;}.is-style-osom-list-with-check-icon li::before {content: "";display: inline-block;background-image: url(' . get_template_directory_uri() . '/assets/images/check-circle-osom.svg);width: 52px;height: 52px;position: absolute;left: 0;top: 50%;transform: translateY(-50%);}@media only screen and (max-width: 600px) {ul.is-style-osom-list-with-check-icon li {margin: 30px 30px 30px 10px;padding-left: 60px;}}',
	) );

	register_block_style(
		'core/post-date',
		array(
			'name'         => 'osom-date-with-icon',
			'label'        => __( 'Calendar Icon', 'dakota-next' ),
			'is_default'   => false,
			'inline_style' => '.wp-block-post-date.is-style-osom-date-with-icon::before {content: "";display: inline-block;margin-right: 5px;color: #938e8e;background-image: url(' . get_template_directory_uri() . '/assets/images/calendar-alt.svg);background-size: 15px 15px;height: 15px;width: 15px;}',
		)
	);

	register_block_style(
		'core/post-terms',
		array(
			'name'         => 'osom-terms-with-icon',
			'label'        => __( 'Tag Icon', 'dakota-next' ),
			'is_default'   => false,
			'inline_style' => '.wp-block-post-terms.is-style-osom-terms-with-icon::before {content: "";display: inline-block;margin-right: 5px;color: #938e8e;background-image: url(' . get_template_directory_uri() . '/assets/images/tags.svg);background-size: 15px 15px;height: 15px;width: 15px;}',
		)
	);

	register_block_style( 'core/cover', array(
		'name'         => 'osom-overlay-text-reveal',
		'label'        => __( 'Text Reveal', 'dakota-next' ),
		'is_default'   => false,
		'inline_style' => '.wp-block-cover.is-style-osom-overlay-text-reveal {overflow: hidden;}.wp-block-cover.is-style-osom-overlay-text-reveal:where(:not(:hover,:focus-within,.is-selected)).wp-block-cover__background {opacity: 0;}.wp-block-cover.is-style-osom-overlay-text-reveal:where(:not(:hover,:focus-within,.is-selected,:has(.wp-block-cover__image-background))).wp-block-cover__background.has-background-gradient {opacity: 1;}.wp-block-cover.is-style-osom-overlay-text-reveal .wp-block-cover__inner-container {opacity: 0;transition: opacity 0.5s ease-in-out;}.wp-block-cover.is-style-osom-overlay-text-reveal:hover .wp-block-cover__inner-container,.wp-block-cover.is-style-osom-overlay-text-reveal:focus-within .wp-block-cover__inner-container,.wp-block-cover.is-style-osom-overlay-text-reveal.is-selected .wp-block-cover__inner-container {opacity: 1;}.wp-block-cover.is-style-osom-overlay-text-reveal .wp-block-cover__background {opacity: 0;}.wp-block-cover.is-style-osom-overlay-text-reveal:hover .wp-block-cover__background {opacity: 0.7;}.wp-block-cover-link > :where(:not(.alignwide):not(.alignfull)) {max-width: 840px;margin-left: auto !important;margin-right: auto !important;}.wp-block-cover-link.alignwide {max-width: 100%;}.wp-block-cover-link.alignfull {max-width: none;}',
	) );

	register_block_style(
		'core/navigation',
		array(
			'name'         => 'osom-rss-menu',
			'label'        => __( 'RSS Menu', 'dakota-next' ),
			'is_default'   => false,
			'inline_style' => '.wp-block-navigation__container.is-style-osom-rss-menu::before {
			display: inline-block;
					content: "";
					width: 20px;
					height: 20px;
					background: url(' . get_template_directory_uri() . '/assets/images/rss.svg);
					}',
		)
	);
}

/**
 * Register block styles only if EDD is active
 */
add_action( 'init', 'osom_register_custom_block_styles_if_edd_active' );
function osom_register_custom_block_styles_if_edd_active() {
	if ( ! function_exists( 'is_plugin_active' ) ) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}

	if ( is_plugin_active( 'easy-digital-downloads/easy-digital-downloads.php' ) ||
		is_plugin_active( 'easy-digital-downloads-pro/easy-digital-downloads-pro.php' ) ) {
		register_block_style( 'edd/downloads', array(
			'name'         => 'osom-edd-downloads',
			'label'        => __( 'Osom EDD Downloads', 'dakota-next' ),
			'inline_style' => '.is-style-osom-edd-downloads .edd-blocks__download{box-shadow:var(--wp--preset--shadow--right-shadow);padding:20px;text-align:center} .is-style-osom-edd-downloads .edd-blocks__buy-button .edd-submit{background:var(--wp--preset--color--primary);padding:10px 20px;text-transform:uppercase;border:none;margin:20px auto;}.is-style-osom-edd-downloads .edd-blocks__buy-button .edd-submit:hover{background:var(--wp--preset--color--primary-darker)}',
		) );

		register_block_style( 'edd/checkout', array(
			'name'         => 'osom-edd-checkout',
			'label'        => __( 'Osom EDD Checkout', 'dakota-next' ),
			'inline_style' => '.is-style-osom-edd-checkout .edd-blocks-form__cart .edd_cart_item_image img { max-width: 150px;max-height:150px;}.is-style-osom-edd-checkout .edd-blocks-cart__row-header.edd_cart_header_row{background:var(--wp--preset--color--secondary)}.is-style-osom-edd-checkout.wp-block-edd-checkout #edd_purchase_form .edd-blocks-form input[type=email],.is-style-osom-edd-checkout.wp-block-edd-checkout #edd_purchase_form .edd-blocks-form input[type=password],.is-style-osom-edd-checkout.wp-block-edd-checkout #edd_purchase_form .edd-blocks-form input[type=text],.is-style-osom-edd-checkout.wp-block-edd-checkout #edd_purchase_form .edd-blocks-form select{padding:10px}.is-style-osom-edd-checkout .edd-blocks-form__cart .edd_cart_footer_row{text-align:center;background:var(--wp--preset--color--secondary)}.is-style-osom-edd-checkout .edd-blocks-cart__row-header.edd_cart_header_row{background:var(--wp--preset--color--secondary)}.is-style-osom-edd-checkout .edd-blocks-form__cart #edd_checkout_cart{border:none}',
		) );
	}
}

// Modify cover block attributes if featured image url is empty (No me funcionaba usando solo el condicional del blockName. Igual tampoco es necesario)
add_filter( 'render_block_data', 'osom_set_cover_block_attributes' );
function osom_set_cover_block_attributes( $parsed_block ) {

	if ( 'core/cover' === $parsed_block['blockName'] && isset( $parsed_block['attrs']['className'] ) && 'is-style-osom-overlay-text-reveal' === $parsed_block['attrs']['className'] && isset( $parsed_block['attrs']['useFeaturedImage'] ) && true === $parsed_block['attrs']['useFeaturedImage'] && isset( $parsed_block['attrs']['url'] ) && '' === $parsed_block['attrs']['url'] ) {
		$parsed_block['attrs']['overlayColor'] = '#000000';
		$parsed_block['attrs']['dimRatio']     = '80';
	}

	return $parsed_block;
}

// Add link to cover block when featured image it's selected and has overlay styles
add_filter( 'render_block_core/cover', 'osom_wrap_cover_block_in_link', 10, 2 );
function osom_wrap_cover_block_in_link( $block_content, $block ) {
	if ( isset( $block['attrs']['className'] ) && 'is-style-osom-overlay-text-reveal' === $block['attrs']['className'] && isset( $block['attrs']['useFeaturedImage'] ) && true === $block['attrs']['useFeaturedImage'] ) {
		global $post;
		$post_url    = get_permalink( $post->ID );
		$align_class = '';
		if ( isset( $block['attrs']['align'] ) ) {
			$align_class = ' align' . $block['attrs']['align'];
		}
		$block_content = '<a href="' . esc_url( $post_url ) . '" class="wp-block-cover-link' . esc_attr( $align_class ) . '">' . $block_content . '</a>';
	}
	return $block_content;
}

// Display current year using block binding
add_action( 'init', 'osom_register_current_year' );
function osom_register_current_year() {
	register_block_bindings_source( 'osom/current-year', array(
		'label'              => __( 'Current Year', 'dakota-next' ),
		'get_value_callback' => function ( array $source_args, WP_Block $block_instance, string $attribute_name ) {
			return date( 'Y' );
		},
	) );
}

// Create a block variation to display the current year
add_filter( 'get_block_type_variations', 'osom_register_current_year_block_variation', 10, 2 );
function osom_register_current_year_block_variation( $variations, $block_type ) {
	if ( 'core/paragraph' === $block_type->name ) {
		$variations[] = array(
			'name'        => 'current-year',
			'title'       => __( 'Current year', 'dakota-next' ),
			'icon'        => 'clock',
			'description' => __( 'Dynamic block that displays the current year on the frontend of the website', 'dakota-next' ),
			'attributes'  => array(
				'className'   => 'current-year',
				'content'     => 'YYYY',
				'metadata'    => array(
					'bindings' => array(
						'content' => array(
							'source' => 'osom/current-year',
						),
					),
					'name'     => 'Current Year',
				),
				'placeholder' => __( 'Current Year', 'dakota-next' ),
			),
		);
	}
	return $variations;
}

// Setup Merlin WP for demo content
require_once get_parent_theme_file_path( '/inc/merlin/vendor/autoload.php' );
require_once get_parent_theme_file_path( '/inc/merlin/class-merlin.php' );
require_once get_parent_theme_file_path( '/inc/merlin-config.php' );

add_filter( 'merlin_import_files', 'osom_merlin_local_import_files' );
function osom_merlin_local_import_files() {
	return array(
		array(
			'import_file_name'             => 'Demo Content',
			'local_import_file'            => get_parent_theme_file_path( '/inc/demo-content.xml' ),
			'import_preview_image_url'     => 'https://demo.osompress.com/dakota-next/wp-content/uploads/sites/10/2024/12/screenshot.webp',
			'import_notice'                => __( 'A special note for this import.', 'dakota-next' ),
			'preview_url'                  => 'https://demo.osompress.com/dakota-next/',
		),
	);
}
